@@ -66,7 +66,7 @@ int32_t SPVM__MIME__Base64__encode_base64(SPVM_ENV* env, SPVM_VALUE* stack) {
         void* obj_str = stack[0].oval;
         
         if (!obj_str) {
-                return env->die(env, stack, "The $string must be defined", __func__, FILE_NAME, __LINE__);
+                return env->die(env, stack, "$string must be defined", __func__, FILE_NAME, __LINE__);
         }
 
         rlen = env->length(env, stack, obj_str);
@@ -150,7 +150,7 @@ int32_t SPVM__MIME__Base64__decode_base64(SPVM_ENV* env, SPVM_VALUE* stack) {
         void* obj_str = stack[0].oval;
         
         if (!obj_str) {
-                return env->die(env, stack, "The $string must be defined", __func__, FILE_NAME, __LINE__);
+                return env->die(env, stack, "$string must be defined", __func__, FILE_NAME, __LINE__);
         }
         
         len = env->length(env, stack, obj_str);
@@ -215,7 +215,7 @@ int32_t SPVM__MIME__Base64__encoded_base64_length(SPVM_ENV* env, SPVM_VALUE* sta
         void* obj_str = stack[0].oval;
         
         if (!obj_str) {
-          return env->die(env, stack, "The $string must be defined", __func__, FILE_NAME, __LINE__);
+          return env->die(env, stack, "$string must be defined", __func__, FILE_NAME, __LINE__);
         }
 
         void* obj_eol = stack[1].oval;
@@ -247,7 +247,7 @@ int32_t SPVM__MIME__Base64__decoded_base64_length(SPVM_ENV* env, SPVM_VALUE* sta
         void* obj_str = stack[0].oval;
         
         if (!obj_str) {
-                return env->die(env, stack, "The $string must be defined", __func__, FILE_NAME, __LINE__);
+                return env->die(env, stack, "$string must be defined", __func__, FILE_NAME, __LINE__);
         }
         
         len = env->length(env, stack, obj_str);
